package com.diagbot.web;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.GetConsoleOnTrialDTO;
import com.diagbot.dto.GetConsoleOpenedDTO;
import com.diagbot.dto.OpenUpOnTrialDTO;
import com.diagbot.dto.ProductAuthProgressDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.facade.OpenedProductsFacade;
import com.diagbot.facade.ProductOrderFacade;
import com.diagbot.vo.OpenUpOnTrialVO;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * 
 * @author rgb
 *
 */
@Api(value="控制台-产品操作", tags={"控制台-产品操作"})
@RestController
@RequestMapping("/productOrder")
public class ProductOrderController {

	@Autowired
	private ProductOrderFacade productOrderFacade;
	@Autowired
	private OpenedProductsFacade openedProductsFacade;

	@ApiOperation(value = "控制台-产品认证进度",notes="控制台-产品认证进度")
	@PostMapping("/productAuthProgress")
	@SysLogger("productAuthProgress")
	public RespDTO<List<ProductAuthProgressDTO>> productAuthProgress() {
		return RespDTO.onSuc(productOrderFacade.productAuthProgress());
	}
	
	@ApiOperation(value = "控制台-已开通产品",notes="控制台-已开通产品")
	@PostMapping("/getConsoleOpened")
	@SysLogger("getConsoleOpened")
	public RespDTO<List<GetConsoleOpenedDTO>> getConsoleOpened() {
		return RespDTO.onSuc(openedProductsFacade.getConsoleOpened());
	}
	
	@ApiOperation(value = "控制台-可试用产品",notes="控制台-可试用产品")
	@PostMapping("/getConsoleOnTrial")
	@SysLogger("getConsoleOnTrial")
	public RespDTO<List<GetConsoleOnTrialDTO>> getConsoleOnTrial() {
		return RespDTO.onSuc(openedProductsFacade.getConsoleOnTrial());
	}
	
	@ApiOperation(value = "控制台-产品立即试用接口",notes="控制台-产品立即试用接口")
	@PostMapping("/openUpOnTrial")
	@SysLogger("openUpOnTrial")
	public RespDTO<OpenUpOnTrialDTO> openUpOnTrial(OpenUpOnTrialVO openUpOnTrialVO) {
		return RespDTO.onSuc(openedProductsFacade.openUpOnTrial(openUpOnTrialVO));
	}

}
